# -*- coding: utf-8 -*-

import unittest
import cos2

from common  import *
from cos2 import utils



class TestMultipart(CosTestCase):
    def test_multipart(self):
        key = "large"
        content = random_bytes(5*1024* 1024)

        parts = []

        upload_id = self.bucket.init_multipart_upload(key).upload_id
        for i in range (1,10):
            result = self.bucket.upload_part(key, upload_id, i, content)
            parts.append(cos2.models.PartInfo(i, result.etag))
        self.bucket.complete_multipart_upload(key, upload_id, parts)

        result = self.bucket.get_object(key).read()
        #self.assertEqual(utils.md5_string(content), utils.md5_string(result))

        parts = []

        upload_id = self.bucket.init_multipart_upload(key).upload_id
        for i in range (1,20):
            result = self.bucket.upload_part(key, upload_id, i, content)
            parts.append(cos2.models.PartInfo(i, result.etag))

        self.bucket.complete_multipart_upload(key, upload_id, parts)

        result = self.bucket.get_object(key).read()
        #self.assertEqual(utils.md5_string(content), utils.md5_string(result))
        self.assertEqual(self.bucket.head_object(key).status,200)
        self.assertEqual(self.bucket.delete_object(key).status,200)


    def test_upload(self):
        filename = "my-first-cos-upload.txt"
        content = cos2.to_bytes(random_string(10 *1024 * 1024 ))

        with open(filename, 'wb') as fileobj:
            fileobj.write(content)


# 也可以直接调用分片上传接口。
# 首先可以用帮助函数设定分片大小，设我们期望的分片大小为128KB
        total_size = os.path.getsize(filename)
        part_size = cos2.determine_part_size(total_size, preferred_size=5*1024*1024)

# 初始化分片上传，得到Upload ID。接下来的接口都要用到这个Upload ID。
        key = 'remote-multipart.txt'
        upload_id = self.bucket.init_multipart_upload(key).upload_id

# 逐个上传分片
# 其中cos2.SizedFileAdapter()把fileobj转换为一个新的文件对象，新的文件对象可读的长度等于num_to_upload
        with open(filename, 'rb') as fileobj:
            parts = []
            part_number = 1
            offset = 0
            while offset < total_size:
                num_to_upload = min(part_size, total_size - offset)
                result = self.bucket.upload_part(key, upload_id, part_number,
                                    cos2.SizedFileAdapter(fileobj, num_to_upload))
                parts.append(cos2.models.PartInfo(part_number, result.etag))

                offset += num_to_upload
                part_number += 1

    # 完成分片上传
        self.bucket.complete_multipart_upload(key, upload_id, parts)
        print("complete upload")


# 验证一下
        with open(filename, 'rb') as fileobj:
            assert self.bucket.get_object(key).read() == fileobj.read()

        os.remove(filename)

if __name__ == '__main__':
    unittest.main()


# -*- coding: utf-8 -*-

import os
import cos2

COS_ID = os.getenv("COS_TEST_ACCESS_KEY_ID","6fb51794f303431d88ba78af3e807550")
COS_SECRET = os.getenv("COS_TEST_ACCESS_KEY_SECRET","929c01e27bbe465392868db05e2ceba1")
COS_ENDPOINT = os.getenv("COS_TEST_ENDPOINT","cos-beta.chinac.com")
COS_BUCKET =  os.getenv("COS_TEST_BUCKET","img-sample")
COS_WEBSITE_ENDPOINT = os.getenv("COS_WEBSITE_ENDPOINT","cos-beta-website.chinac.com")

auth = cos2.Auth(COS_ID, COS_SECRET)
service = cos2.Service(auth, COS_ENDPOINT)
bucket = cos2.Bucket(auth,COS_ENDPOINT,COS_BUCKET)
bucket.put_object_from_file("test.mp4","/Users/miya/Downloads/test.mp4")




#bucket.create_bucket("public-read")
#bucket.delete_bucket()
#for objectinfo in bucket.list_objects().object_list:

for objectinfo in bucket.list_objects().object_list:
          #bucket.delete_object(objectinfo.key)
          print(objectinfo.key)

#bucket.delete_bucket()
#print(objectinfo.key)


#bucket.create_bucket()
for bucketinfo in service.list_buckets().buckets:
     print(bucketinfo.name)
#     bucket = cos2.Bucket(auth, COS_ENDPOINT, bucketinfo.name)
#




import os
import cos2
import random


COS_ENDPOINT = os.getenv("COS_TEST_ENDPOINT","http://cos-cn-guangzhou.chinac.com")
COS_WEBSITE_ENDPOINT = os.getenv("COS_WEBSITE_ENDPOINT","http://cos-cn-guangzhou-website.chinac.com")

bucket_src_auth = cos2.Auth("e1eacdfd85df47589a7712251271ec46", "b2a7d846a9e24832a9b1e614caa404a1")
bucket_src = cos2.Bucket(bucket_src_auth,COS_ENDPOINT,"cos-test")

bucket_dst_auth = cos2.Auth("ad039afdb6614e4994a177474dee1356", "d7844d2510d74036825bf21126d48bd8")
bucket_dst = cos2.Bucket(bucket_src_auth,COS_ENDPOINT,"cos-perf-test-1m")


object_list = bucket_src.list_objects().object_list
bucket_dst.create_bucket("public-read")

# for i in range(500,10000):
#      src_objectName =object_list[random.randint(0,len(object_list)-1)].key
#      data = bucket_src.get_object(src_objectName)
#      dst_objectName="img-"+str(i)
#      bucket_dst.put_object(dst_objectName,data)
#      print(src_objectName,dst_objectName)




import  cos2
import uuid
import os


if __name__ == '__main__':

    COS_ID = os.getenv("COS_TEST_ACCESS_KEY_ID")
    COS_SECRET = os.getenv("COS_TEST_ACCESS_KEY_SECRET")
    COS_ENDPOINT = os.getenv("COS_TEST_ENDPOINT")
    COS_BUCKET =  os.getenv("COS_TEST_BUCKET")
    COS_WEBSITE_ENDPOINT = os.getenv("COS_WEBSITE_ENDPOINT")

# print bucketName
    print '==========================================='
    print 'Getting Started with COS SDK for Python'
    print '===========================================\n'

# Init COS Python SDK
    auth = cos2.Auth(COS_ID, COS_SECRET)
    bucket = cos2.Bucket(auth, COS_ENDPOINT, COS_BUCKET)

# Create a new COS PublicRead bucket
    print 'Creating bucket ' + COS_BUCKET
# bucket.create_bucket(cos2.BUCKET_ACL_PUBLIC_READ)
    bucket.create_bucket()

# List the buckets in your account
    print 'Listing buckets'
    service = cos2.Service(auth, COS_ENDPOINT, connect_timeout=30)
    for bucketInfo in service.list_buckets().buckets:
        print ' - ' + bucketInfo.name

# Upload an object to your bucket
    print 'Uploading a new object to COS from memory'
    content = 'Thank you for using COS SDK for Python'
    bucket.put_object("cos-test-object", content)


# Determine whether an object residents in your bucket
    exist = bucket.object_exists("cos-test-object")
    print(bucket.get_object("cos-test-object").read())



import unittest
import cos2

from common  import *
from cos2 import utils

class TestMultipart(CosTestCase):
    def test_delete_all_obj(self):
        for bucketInfo in self.service.list_buckets().buckets:
           for object in self.bucket.list_objects().object_list:
               self.bucket.delete_object(object.key)
           for uploadinfo in self.bucket.list_multipart_uploads().upload_list:
               self.bucket.abort_multipart_upload(uploadinfo.key,uploadinfo.upload_id)

if __name__ == '__main__':
    unittest.main()


# -*- coding: utf-8 -*-

import unittest
import cos2
import socket
import sys
from common import *


class TestApiBase(CosTestCase):

    def test_whitespace(self):
         bucket = cos2.Bucket(cos2.Auth(COS_ID, ' ' + COS_SECRET + ' '), COS_ENDPOINT, COS_BUCKET)
         bucket.get_bucket_acl()

         bucket = cos2.Bucket(cos2.Auth(COS_ID, COS_SECRET), ' ' + COS_ENDPOINT + ' ', COS_BUCKET)
         bucket.get_bucket_acl()

         bucket = cos2.Bucket(cos2.Auth(COS_ID, COS_SECRET), COS_ENDPOINT, ' ' + COS_BUCKET + ' ')
         bucket.get_bucket_acl()

    if sys.version_info >= (3, 3):
        def test_user_agent(self):
            app = 'fantastic-tool'

            assert_found = False
            def do_request(session_self, req, timeout):
                if assert_found:
                    self.assertTrue(req.headers['User-Agent'].find(app) >= 0)
                else:
                    self.assertTrue(req.headers['User-Agent'].find(app) < 0)

                raise cos2.exceptions.ClientError('intentional')

            from unittest.mock import patch
            with patch.object(cos2.Session, 'do_request', side_effect=do_request, autospec=True):
                # 不加 app_name
                assert_found = False
                self.assertRaises(cos2.exceptions.ClientError, self.bucket.get_bucket_acl)

                service = cos2.Service(cos2.Auth(COS_ID, COS_SECRET), COS_ENDPOINT)
                self.assertRaises(cos2.exceptions.ClientError, service.list_buckets)

                # 加app_name
                assert_found = True
                bucket = cos2.Bucket(cos2.Auth(COS_ID, COS_SECRET), COS_ENDPOINT, COS_BUCKET,
                                     app_name=app)
                self.assertRaises(cos2.exceptions.ClientError, bucket.get_bucket_acl)

                service = cos2.Service(cos2.Auth(COS_ID, COS_SECRET), COS_ENDPOINT,
                                       app_name=app)
                self.assertRaises(cos2.exceptions.ClientError, service.list_buckets)


if __name__ == '__main__':
    unittest.main()